@@ -153,10 +153,6 @@ _dbus_header_cache_one (DBusHeader     *header,
                         int             field_code,
                         DBusTypeReader *variant_reader)
 {
-  int variant_type;
-
-  variant_type = _dbus_type_reader_get_current_type (variant_reader);
-
   header->fields[field_code].value_pos =
     _dbus_type_reader_get_value_pos (variant_reader);
 
