@@ -219,6 +219,8 @@ _dbus_write_pid_file (const DBusString *filename,
       dbus_set_error (error, _dbus_error_from_errno (errno),
                       "Failed to write to \"%s\": %s", cfilename,
                       _dbus_strerror (errno));
+      
+      fclose (f);
       return FALSE;
     }
 
@@ -295,7 +297,7 @@ _dbus_set_signal_handler (int               sig,
   act.sa_handler = handler;
   act.sa_mask    = empty_mask;
   act.sa_flags   = 0;
-  sigaction (sig,  &act, 0);
+  sigaction (sig,  &act, NULL);
 }
 
 
